@@ -20,6 +20,7 @@ struct ds_tree_node {
 	struct ds_component *comp;
 
 	unsigned resolved : 1;
+        unsigned dnd_to_import : 1;
 };
 
 struct ds_component
@@ -39,8 +40,11 @@ ds_Tree * ds_delete(char *i, ds_Tree * t);
 #endif
 
 /*
- * $Id: splay.h,v 1.1.1.1 2007/05/30 04:25:38 gtkwave Exp $
+ * $Id: splay.h,v 1.2 2010/06/23 05:40:48 gtkwave Exp $
  * $Log: splay.h,v $
+ * Revision 1.2  2010/06/23 05:40:48  gtkwave
+ * added dnd from gtkwave into rtlbrowse
+ *
  * Revision 1.1.1.1  2007/05/30 04:25:38  gtkwave
  * Imported sources
  *
