@@ -36,6 +36,7 @@ ds_Tree *flattened_mod_list_root = NULL;
 struct gtkwave_annotate_ipc_t *anno_ctx = NULL;
 struct vzt_rd_trace  *vzt=NULL;
 struct lxt2_rd_trace *lx2=NULL;
+void *fst=NULL;
 
 #ifdef AET2_IS_PRESENT
 FILE *aetf;
@@ -257,7 +258,28 @@ if(i==len)
 	int shmid;
 	
 	sscanf(id, "%x", &shmid);
+#ifdef __MINGW32__
+                {
+                HANDLE hMapFile;
+                char mapName[257];
+
+                sprintf(mapName, "rtlbrowse%d", shmid);
+                hMapFile = OpenFileMapping(FILE_MAP_ALL_ACCESS, FALSE, mapName);
+                if(hMapFile == NULL)
+                        {
+                        fprintf(stderr, "Could not attach shared memory map name '%s', exiting.\n", mapName);
+                        exit(255);
+                        }
+                anno_ctx = MapViewOfFile(hMapFile, FILE_MAP_ALL_ACCESS, 0, 0, sizeof(struct gtkwave_annotate_ipc_t));
+                if(anno_ctx == NULL)
+                        {
+                        fprintf(stderr, "Could not map view of file '%s', exiting.\n", mapName);
+                        exit(255);
+                        }
+                }
+#else
 	anno_ctx = shmat(shmid, NULL, 0);
+#endif
 	if(anno_ctx)
 		{
 		if((!memcmp(anno_ctx->matchword, WAVE_MATCHWORD, 4))&&(anno_ctx->aet_type > WAVE_ANNO_NONE)&&(anno_ctx->aet_type < WAVE_ANNO_MAX))
@@ -453,6 +475,15 @@ if(anno_ctx)
 	{
 	switch(anno_ctx->aet_type)
 		{
+		case WAVE_ANNO_FST:
+			fst=fstReaderOpen(anno_ctx->aet_name);
+			if(!fst)         
+			        {
+			        fprintf(stderr, "Could not initialize '%s', exiting.\n", anno_ctx->aet_name);
+			        exit(255);
+			        }   
+			break;
+
 		case WAVE_ANNO_VZT:
 			vzt=vzt_rd_init(anno_ctx->aet_name);
 			if(!vzt)         
@@ -499,8 +530,14 @@ return(0);
 }
 
 /*
- * $Id: stem_recurse.c,v 1.5 2009/01/13 22:39:24 gtkwave Exp $
+ * $Id: stem_recurse.c,v 1.7 2009/06/13 22:02:18 gtkwave Exp $
  * $Log: stem_recurse.c,v $
+ * Revision 1.7  2009/06/13 22:02:18  gtkwave
+ * beginning to add FST support to rtlbrowse
+ *
+ * Revision 1.6  2009/04/23 21:57:53  gtkwave
+ * added mingw support for rtlbrowse
+ *
  * Revision 1.5  2009/01/13 22:39:24  gtkwave
  * compile fixes for mingw
  *
