@@ -13,7 +13,6 @@
 #define GHW_H
 
 #include <limits.h>
-#include "ghwlib.h"
 #include "tree.h"
 #include "vcd.h"
 
@@ -25,8 +24,11 @@ int strand_pnt(char *s);
 #endif
 
 /*
- * $Id: ghw.h,v 1.2 2007/08/26 21:35:40 gtkwave Exp $
+ * $Id: ghw.h,v 1.3 2009/12/29 07:07:49 gtkwave Exp $
  * $Log: ghw.h,v $
+ * Revision 1.3  2009/12/29 07:07:49  gtkwave
+ * fixes for ghw files
+ *
  * Revision 1.2  2007/08/26 21:35:40  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
