@@ -159,6 +159,7 @@ TimeType atoi_64(char *str)
 TimeType val=0;
 unsigned char ch, nflag=0;
 
+#if 0
 switch(*str)
 	{
 	case 'y':
@@ -181,6 +182,7 @@ switch(*str)
 	default:
 		break;
 	}
+#endif
 
 while((ch=*(str++)))
 	{
@@ -203,8 +205,11 @@ return(nflag?(-val):val);
 }
 
 /*
- * $Id: v2l_debug.c,v 1.1.1.1 2007/05/30 04:28:18 gtkwave Exp $
+ * $Id: v2l_debug.c,v 1.2 2009/04/20 18:48:12 gtkwave Exp $
  * $Log: v2l_debug.c,v $
+ * Revision 1.2  2009/04/20 18:48:12  gtkwave
+ * mingw fixes
+ *
  * Revision 1.1.1.1  2007/05/30 04:28:18  gtkwave
  * Imported sources
  *
