@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Tony Bybell.
+ * Copyright (c) 2009-2010 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -86,6 +86,7 @@ int line = 0;
 size_t ss;
 fstHandle returnedhandle;
 JRB node;
+uint64_t prev_tim = 0;
 char bin_fixbuff[32769];
 
 if(!strcmp("-", vname))
@@ -166,6 +167,11 @@ while(!feof(f))
 					{
 					vartype = FST_VT_VCD_REAL_PARAMETER;
 					}
+				else
+				if(!strcmp(st, "realtime"))
+					{
+					vartype = FST_VT_VCD_REALTIME;
+					}
 				break;
 				
 			case 'p':
@@ -523,7 +529,11 @@ while(!feof(f))
 
 		case '#':
 			sscanf(buf+1, "%"SCNu64, &tim);
-			fstWriterEmitTimeChange(ctx, tim);
+			if((tim >= prev_tim)||(!prev_tim))
+				{
+				prev_tim = tim;
+				fstWriterEmitTimeChange(ctx, tim);
+				}
 			break;
 
 		default:
@@ -694,8 +704,14 @@ return(0);
 }
 
 /*
- * $Id: vcd2fst.c,v 1.8 2009/08/06 20:03:31 gtkwave Exp $
+ * $Id: vcd2fst.c,v 1.10 2010/02/22 21:13:37 gtkwave Exp $
  * $Log: vcd2fst.c,v $
+ * Revision 1.10  2010/02/22 21:13:37  gtkwave
+ * added "realtime" VCD variable
+ *
+ * Revision 1.9  2010/02/08 17:31:19  gtkwave
+ * backtracking time fix
+ *
  * Revision 1.8  2009/08/06 20:03:31  gtkwave
  * warnings fixes
  *
