@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2009 Tony Bybell.
+ * Copyright (c) 2001-2010 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -111,24 +111,24 @@ static struct vcdsymbol **sorted=NULL;
 static struct vcdsymbol **indexed=NULL;
 
 enum VarTypes { V_EVENT, V_PARAMETER,
-                V_INTEGER, V_REAL, V_REAL_PARAMETER=V_REAL, V_REG, V_SUPPLY0,
+                V_INTEGER, V_REAL, V_REAL_PARAMETER=V_REAL, V_REALTIME=V_REAL, V_REG, V_SUPPLY0,
                 V_SUPPLY1, V_TIME, V_TRI, V_TRIAND, V_TRIOR,
                 V_TRIREG, V_TRI0, V_TRI1, V_WAND, V_WIRE, V_WOR, V_PORT, V_IN=V_PORT, V_OUT=V_PORT, V_INOUT=V_PORT,
                 V_END, V_LB, V_COLON, V_RB, V_STRING };
 
 static char *vartypes[]={ "event", "parameter",
-                "integer", "real", "real_parameter", "reg", "supply0",
+                "integer", "real", "real_parameter", "realtime", "reg", "supply0",
                 "supply1", "time", "tri", "triand", "trior",
                 "trireg", "tri0", "tri1", "wand", "wire", "wor", "port", "in", "out", "inout",
                 "$end", "", "", "", ""};
 
 static const unsigned char varenums[] = {  V_EVENT, V_PARAMETER,
-                V_INTEGER, V_REAL, V_REAL_PARAMETER, V_REG, V_SUPPLY0,
+                V_INTEGER, V_REAL, V_REAL_PARAMETER, V_REALTIME, V_REG, V_SUPPLY0,
                 V_SUPPLY1, V_TIME, V_TRI, V_TRIAND, V_TRIOR,
                 V_TRIREG, V_TRI0, V_TRI1, V_WAND, V_WIRE, V_WOR, V_PORT, V_IN, V_OUT, V_INOUT,
                 V_END, V_LB, V_COLON, V_RB, V_STRING };
 
-#define NUM_VTOKENS 23  
+#define NUM_VTOKENS 24  
 
 static int numsyms=0;
 
@@ -1390,6 +1390,12 @@ for(;;)
 						{
 						start_time=time;
 						}
+
+					if(time < current_time) /* avoid backtracking time counts which can happen on malformed files */
+						{
+						time = current_time; 
+						}
+
                                         current_time=time;
                                         if(end_time<time) end_time=time;        /* in case of malformed vcd files */
 					lt_set_time64(lt, current_time);
@@ -1949,8 +1955,14 @@ exit(0);
 }
 
 /*
- * $Id: vcd2lxt.c,v 1.6 2009/07/07 19:46:03 gtkwave Exp $
+ * $Id: vcd2lxt.c,v 1.8 2010/02/22 21:13:37 gtkwave Exp $
  * $Log: vcd2lxt.c,v $
+ * Revision 1.8  2010/02/22 21:13:37  gtkwave
+ * added "realtime" VCD variable
+ *
+ * Revision 1.7  2010/02/08 17:31:19  gtkwave
+ * backtracking time fix
+ *
  * Revision 1.6  2009/07/07 19:46:03  gtkwave
  * make evcd->vcd conversion table const
  *
