@@ -1670,7 +1670,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 			}
                 s=&sym_block[i];
                 symadd_name_exists_sym_exists(s,str,0);
-		if((prevsym)&&(i>0)&&(!strcmp(f_name[i], f_name[i-1])))	/* allow chaining for search functions.. */
+		if((prevsym)&&(i>0)&&(!strcmp(f_name[i], f_name[i-1]))&&(!strchr(f_name[i], '\\'))) /* allow chaining for search functions.. */
 			{
 			prevsym->vec_root = prevsymroot;
 			prevsym->vec_chain = s;
@@ -2406,8 +2406,11 @@ np->numhist++;
 }
 
 /*
- * $Id: lxt.c,v 1.19 2010/03/14 07:09:49 gtkwave Exp $
+ * $Id: lxt.c,v 1.20 2010/06/02 03:51:30 gtkwave Exp $
  * $Log: lxt.c,v $
+ * Revision 1.20  2010/06/02 03:51:30  gtkwave
+ * don't autocoalesce escape identifiers
+ *
  * Revision 1.19  2010/03/14 07:09:49  gtkwave
  * removed ExtNode and merged with Node
  *
