@@ -29,6 +29,7 @@
 #include "symbol.h"
 #include "main.h"
 
+void do_popup_menu (GtkWidget *my_widget, GdkEventButton *event);
 void get_main_menu (GtkWidget *, GtkWidget **menubar);
 void menu_set_sensitive(void);
 int file_quit_cmd_callback (GtkWidget *widget, gpointer data);
@@ -71,7 +72,6 @@ WV_MENU_TCLSCR,
 WV_MENU_TCLSEP,
 #endif
 WV_MENU_FQY,
-WV_MENU_FQN,
 WV_MENU_ESTMH,
 WV_MENU_ETH,
 WV_MENU_SEP3,
@@ -351,8 +351,14 @@ bvptr combine_traces(int direction, Trptr single_trace_only);
 #endif
 
 /*
- * $Id: menu.h,v 1.37 2010/06/13 20:38:00 gtkwave Exp $
+ * $Id: menu.h,v 1.39 2010/07/01 23:02:41 gtkwave Exp $
  * $Log: menu.h,v $
+ * Revision 1.39  2010/07/01 23:02:41  gtkwave
+ * header file cleanup
+ *
+ * Revision 1.38  2010/06/29 02:05:14  gtkwave
+ * changed quit accelerator
+ *
  * Revision 1.37  2010/06/13 20:38:00  gtkwave
  * added strace repeat count
  *
