@@ -567,9 +567,10 @@ ps_MaxSignalLength (void)
   int vlen = 0;
   int i, trwhich, trtarget, num_traces_displayable;
   GtkAdjustment *sadj;
-  char sbuf[128];
-  int bufxlen;
-  int bufclen;
+  char buf[2048];
+  bvptr bv;
+  Trptr tscan;
+
 
   GLOBALS->ps_nummaxchars_print_c_1 = 7;	/* allows a good spacing if 60 pixel default
 						 * is used */
@@ -597,56 +598,102 @@ ps_MaxSignalLength (void)
 
   for (i = 0; (i < num_traces_displayable) && (t); i++)
     {
+    char *subname = NULL;  
+    bv = NULL;
+    tscan = NULL;  
+                      
+  if(t->flags & (TR_BLANK|TR_ANALOG_BLANK_STRETCH))  /* seek to real xact trace if present... */
+        {
+        int bcnt = 0;
+        tscan = t;
+        while((tscan) && (tscan = GivePrevTrace(tscan)))
+                {
+                if(!(tscan->flags & (TR_BLANK|TR_ANALOG_BLANK_STRETCH)))
+                        {
+                        if(tscan->flags & TR_TTRANSLATED)
+                                {
+                                break; /* found it */
+                                }
+                                else
+                                {
+                                tscan = NULL;
+                                }
+                        }
+                        else
+                        {
+                        bcnt++; /* bcnt is number of blank traces */
+                        }
+                }
+           
+        if((tscan)&&(tscan->vector))
+                {
+                bv = tscan->n.vec;
+                do
+                        {
+                        bv = bv->transaction_chain; /* correlate to blank trace */
+                        } while(bv && (bcnt--));
+                if(bv)
+                        {
+                        subname = bv->bvname;
+                        if(GLOBALS->hier_max_level)
+                                subname = hier_extract(subname, GLOBALS->hier_max_level);
+                        }
+                }
+        }
+                        
+    populateBuffer(t, subname, buf);
 
-      sbuf[0] = 0;
-      bufxlen = bufclen = 0;
-      if ((GLOBALS->shift_timebase = t->shift))
+      if (!bv && (t->flags & (TR_BLANK | TR_ANALOG_BLANK_STRETCH))) /* for "comment" style blank traces */
 	{
-	  sbuf[0] = '(';
-	  reformat_time (sbuf + 1, t->shift, GLOBALS->time_dimension);
-	  strcpy (sbuf + (bufclen = strlen (sbuf + 1) + 1), ")");
-	  bufclen++;
-	  bufxlen = font_engine_string_measure (GLOBALS->signalfont, sbuf);
-	}
-
-      if ((!t->vector) && (t->n.nd) && (t->n.nd->array_height))
-	{
-	  bufclen +=
-	    sprintf (sbuf + strlen (sbuf), "{%d}", t->n.nd->this_row);
-	  bufxlen = font_engine_string_measure (GLOBALS->signalfont, sbuf);
-	}
-
-      if (t->flags & (TR_BLANK | TR_ANALOG_BLANK_STRETCH))
-	{
-	  if (t->name)
+	  if (buf[0])
 	    {
 	      len =
-		font_engine_string_measure (GLOBALS->signalfont, t->name) + bufxlen;
-	      numchars = strlen (t->name) + bufclen;
+		font_engine_string_measure (GLOBALS->signalfont, buf);
+	      numchars = strlen (buf);
 
 	      if (len > maxlen)
 		maxlen = len;
 	      if (numchars > GLOBALS->ps_nummaxchars_print_c_1)
 		GLOBALS->ps_nummaxchars_print_c_1 = numchars;
+
+              if(t->asciivalue)
+                {
+                free_2(t->asciivalue); t->asciivalue = NULL;
+                }
 	    }
 	}
-      else if (t->name)
+      else if (buf[0] || subname)
 	{
-	  len = font_engine_string_measure (GLOBALS->signalfont, t->name) + bufxlen;
-	  numchars = strlen (t->name) + bufclen;
+	  len = font_engine_string_measure (GLOBALS->signalfont, buf);
+	  numchars = strlen (buf);
 	  if ((GLOBALS->tims.marker != -1) && (!(t->flags & TR_EXCLUDE)))
 	    {
 	      t->asciitime = GLOBALS->tims.marker;
 	      if (t->asciivalue)
 		free_2 (t->asciivalue);
 
-	      if (t->vector)
+	      if (bv || t->vector)
 		{
 		  char *str, *str2;
 		  vptr v;
+                  Trptr ts;
+                  TraceEnt t_temp;
 
-		  v = bsearch_vector (t->n.vec, GLOBALS->tims.marker);
-		  str = convert_ascii (t, v);
+                  if(bv)
+			{
+                        ts = &t_temp;
+                        memcpy(ts, tscan, sizeof(TraceEnt));
+                        ts->vector = 1;
+                        ts->n.vec = bv;
+                        }
+                        else
+                        {
+                        ts = t;
+                        bv = t->n.vec;
+                        }
+
+		  v = bsearch_vector (bv, GLOBALS->tims.marker - ts->shift);
+		  str = convert_ascii (ts, v);
 		  if (str)
 		    {
 		      int slen;
@@ -683,7 +730,7 @@ ps_MaxSignalLength (void)
 		  char *str;
 		  hptr h_ptr;
 
-		  if ((h_ptr = bsearch_node (t->n.nd, GLOBALS->tims.marker)))
+		  if ((h_ptr = bsearch_node (t->n.nd, GLOBALS->tims.marker - t->shift)))
 		    {
 		      if (!t->n.nd->extvals)
 			{
@@ -717,7 +764,7 @@ ps_MaxSignalLength (void)
 			      if (!(h_ptr->flags & HIST_STRING))
 				{
 				  str =
-				    convert_ascii_real ((double *) h_ptr->v.
+				    convert_ascii_real (t, (double *) h_ptr->v.
 							h_vector);
 				}
 			      else
@@ -1840,9 +1887,6 @@ yt1 = coords[3];
       h = h->next;
       lasttype = type;
     }
-
-  GLOBALS->tims.start += GLOBALS->shift_timebase;
-  GLOBALS->tims.end += GLOBALS->shift_timebase;
 }
 
 static void
@@ -1922,6 +1966,8 @@ pr_draw_hptr_trace_vector (pr_context * prc, Trptr t, hptr h, int which)
 	}
 
       pr_draw_hptr_trace_vector_analog (prc, t, h, which, ext);
+      GLOBALS->tims.start -= GLOBALS->shift_timebase;
+      GLOBALS->tims.end -= GLOBALS->shift_timebase;
       return;
     }
 
@@ -2035,12 +2081,14 @@ pr_draw_hptr_trace_vector (pr_context * prc, Trptr t, hptr h, int which)
 
 	      if (width > GLOBALS->vector_padding)
 		{
+		char *t_ascii; /* to skip past color ? ? string */
+
 		  if (h->flags & HIST_REAL)
 		    {
 		      if (!(h->flags & HIST_STRING))
 			{
 			  ascii =
-			    convert_ascii_real ((double *) h->v.h_vector);
+			    convert_ascii_real (t, (double *) h->v.h_vector);
 			}
 		      else
 			{
@@ -2053,15 +2101,16 @@ pr_draw_hptr_trace_vector (pr_context * prc, Trptr t, hptr h, int which)
 		      ascii = convert_ascii_vec (t, h->v.h_vector);
 		    }
 
+		  if((*ascii=='?')&&((t_ascii=strchr(ascii+1, '?')))) { t_ascii++; } else { t_ascii = ascii; }
 
 		  if (((pixlen =
 			font_engine_string_measure (GLOBALS->wavefont,
-					    ascii)) +
+					    t_ascii)) +
 		       GLOBALS->vector_padding <= width)
 		      || ((_x1 >= GLOBALS->wavewidth)
 			  && (prc->gpd == &ps_print_device)))
 		    {
-		      pr_draw_string (prc, _x0 + 2, ytext, ascii, pixlen,
+		      pr_draw_string (prc, _x0 + 2, ytext, t_ascii, pixlen,
 				      ysiz);
 		    }
 		  else
@@ -2069,13 +2118,13 @@ pr_draw_hptr_trace_vector (pr_context * prc, Trptr t, hptr h, int which)
 		      char *mod;
 
 		      mod =
-			bsearch_trunc (ascii,
+			bsearch_trunc (t_ascii,
 				       width - GLOBALS->vector_padding);
 		      if (mod)
 			{
 			  *mod = '+';
 			  *(mod + 1) = 0;
-			  pr_draw_string (prc, _x0 + 2, ytext, ascii,
+			  pr_draw_string (prc, _x0 + 2, ytext, t_ascii,
 					  GLOBALS->maxlen_trunc, ysiz);
 			}
 		    }
@@ -2474,7 +2523,6 @@ pr_draw_vptr_trace (pr_context * prc, Trptr t, vptr v, int which)
   GLOBALS->tims.start -= GLOBALS->shift_timebase;
   GLOBALS->tims.end -= GLOBALS->shift_timebase;
 
-  h = v;
   liney = ((which + 2) * GLOBALS->fontheight) - 2;
   _y1 = ((which + 1) * GLOBALS->fontheight) + 2;
   _y0 = liney - 2;
@@ -2507,6 +2555,8 @@ pr_draw_vptr_trace (pr_context * prc, Trptr t, vptr v, int which)
 	}
     }
 
+  h = v;
+
   if (t->flags & TR_ANALOGMASK)
     {
       Trptr te = GiveNextTrace(t);
@@ -2526,6 +2576,9 @@ pr_draw_vptr_trace (pr_context * prc, Trptr t, vptr v, int which)
 	}
 
       pr_draw_vptr_trace_analog (prc, t, v, which, ext);
+
+      GLOBALS->tims.start+=GLOBALS->shift_timebase;
+      GLOBALS->tims.end+=GLOBALS->shift_timebase;
       return;
     }
 
@@ -2634,16 +2687,19 @@ pr_draw_vptr_trace (pr_context * prc, Trptr t, vptr v, int which)
 
 	      if (width > GLOBALS->vector_padding)
 		{
+		  char *t_ascii;
 		  ascii = convert_ascii (t, h);
 
+		  if((*ascii=='?')&&((t_ascii=strchr(ascii+1, '?')))) { t_ascii++; } else { t_ascii = ascii; }
+
 		  if (((pixlen =
 			font_engine_string_measure (GLOBALS->wavefont,
-					    ascii)) +
+					    t_ascii)) +
 		       GLOBALS->vector_padding <= width)
 		      || ((_x1 >= GLOBALS->wavewidth)
 			  && (prc->gpd == &ps_print_device)))
 		    {
-		      pr_draw_string (prc, _x0 + 2, ytext, ascii, pixlen,
+		      pr_draw_string (prc, _x0 + 2, ytext, t_ascii, pixlen,
 				      ysiz);
 		    }
 		  else
@@ -2651,14 +2707,14 @@ pr_draw_vptr_trace (pr_context * prc, Trptr t, vptr v, int which)
 		      char *mod;
 
 		      mod =
-			bsearch_trunc (ascii,
+			bsearch_trunc (t_ascii,
 				       width - GLOBALS->vector_padding);
 		      if (mod)
 			{
 			  *mod = '+';
 			  *(mod + 1) = 0;
 
-			  pr_draw_string (prc, _x0 + 2, ytext, ascii,
+			  pr_draw_string (prc, _x0 + 2, ytext, t_ascii,
 					  GLOBALS->maxlen_trunc, ysiz);
 			}
 		    }
@@ -2699,25 +2755,49 @@ pr_rendertraces (pr_context * prc)
     }
   if (GLOBALS->topmost_trace)
     {
-      Trptr t;
+      Trptr t = GLOBALS->topmost_trace;
+      Trptr tback = t;
       hptr h;
       vptr v;
-      int i, num_traces_displayable;
+      int i = 0, num_traces_displayable;
+      int iback = 0;
 
       num_traces_displayable =
 	GLOBALS->wavearea->allocation.height / (GLOBALS->fontheight);
       num_traces_displayable--;	/* for the time trace that is
 				 * always there */
 
-      t = GLOBALS->topmost_trace;
-      for (i = 0; ((i < num_traces_displayable) && (t)); i++)
+      /* ensure that transaction traces are visible even if the topmost traces are blanks */
+      while(tback)
+                {
+                if(tback->flags&(TR_BLANK|TR_ANALOG_BLANK_STRETCH))
+                        {
+                        tback = GivePrevTrace(tback);
+                        iback--;
+                        }
+                else if(tback->flags & TR_TTRANSLATED)
+                        {
+                        if(tback != t)
+                                {
+                                t = tback;
+                                i = iback;
+                                }
+                        break;
+                        }
+                else
+                        {
+                        break;
+                        }
+                }
+
+      for (; ((i < num_traces_displayable) && (t)); i++)
 	{
 	  if (!(t->flags & (TR_EXCLUDE | TR_BLANK | TR_ANALOG_BLANK_STRETCH)))
 	    {
 	      GLOBALS->shift_timebase = t->shift;
 	      if (!t->vector)
 		{
-		  h = bsearch_node (t->n.nd, GLOBALS->tims.start);
+		  h = bsearch_node (t->n.nd, GLOBALS->tims.start - t->shift);
 		  DEBUG (printf
 			 ("Bit Trace: %s, %s\n", t->name, t->n.nd->nname));
 		  DEBUG (printf
@@ -2726,23 +2806,49 @@ pr_rendertraces (pr_context * prc)
 
 		  if (!t->n.nd->extvals)
 		    {
-		      pr_draw_hptr_trace (prc, t, h, i, 1, 0);
+		      if(i>=0) pr_draw_hptr_trace (prc, t, h, i, 1, 0);
 		    }
 		  else
 		    {
-		      pr_draw_hptr_trace_vector (prc, t, h, i);
+		      if(i>=0) pr_draw_hptr_trace_vector (prc, t, h, i);
 		    }
 		}
 	      else
 		{
-		  v = bsearch_vector (t->n.vec, GLOBALS->tims.start);
-		  DEBUG (printf
+		Trptr t_orig, tn;
+                bvptr bv = t->n.vec;
+
+		v = bsearch_vector (bv, GLOBALS->tims.start - t->shift);
+		DEBUG (printf
 			 ("Vector Trace: %s, %s\n", t->name, t->n.vec->name));
-		  DEBUG (printf
+		DEBUG (printf
 			 ("Start time: " TTFormat ", Vectorent time: "
 			  TTFormat "\n", tims.start,
 			  (v->time + shift_timebase)));
-		  pr_draw_vptr_trace (prc, t, v, i);
+		if(i>=0) pr_draw_vptr_trace (prc, t, v, i);
+
+                if((bv->transaction_chain) && (t->flags & TR_TTRANSLATED))
+                	{
+                        t_orig = t;
+                        for(;;)
+                        	{
+                                tn = GiveNextTrace(t);
+                                bv = bv->transaction_chain;
+        
+                                if(bv && tn && (tn->flags & (TR_BLANK|TR_ANALOG_BLANK_STRETCH)))
+                                	{
+                                        i++;
+                                        if(i<num_traces_displayable)
+                                        	{
+                                                v=bsearch_vector(bv, GLOBALS->tims.start - t->shift);
+                                                if(i>=0) pr_draw_vptr_trace(prc, t_orig,v,i);
+                                                t = tn;
+                                                continue;
+                                                }
+                                        }
+                                break;
+				}
+                        }
 		}
 	    }
 	  else
@@ -2762,7 +2868,7 @@ pr_rendertraces (pr_context * prc)
 		    }
 		}
 
-	      pr_draw_hptr_trace (prc, NULL, NULL, i, 0, kill_dodraw_grid);
+	      if(i>=0) pr_draw_hptr_trace (prc, NULL, NULL, i, 0, kill_dodraw_grid);
 	    }
 	  t = GiveNextTrace (t);
 	}
@@ -2778,28 +2884,54 @@ pr_RenderSig (pr_context * prc, Trptr t, int i)
 {
   int texty, liney;
   int retval;
-  char sbuf[128];
-  int bufclen;
+  char buf[2048];
+  char *subname = NULL;  
+                        
+  buf[0] = 0;
+                 
+  if(t->flags & (TR_BLANK|TR_ANALOG_BLANK_STRETCH))  /* seek to real xact trace if present... */
+        {
+        Trptr tscan = t;
+        int bcnt = 0;
+        while((tscan) && (tscan = GivePrevTrace(tscan)))
+                {
+                if(!(tscan->flags & (TR_BLANK|TR_ANALOG_BLANK_STRETCH)))
+                        {
+                        if(tscan->flags & TR_TTRANSLATED)
+                                {
+                                break; /* found it */
+                                }
+                                else
+                                {
+                                tscan = NULL;
+                                }
+                        }
+                        else
+                        {
+                        bcnt++; /* bcnt is number of blank traces */
+                        }
+                }
+
+        if((tscan)&&(tscan->vector))
+                {
+                bvptr bv = tscan->n.vec;
+                do
+                        {
+                        bv = bv->transaction_chain; /* correlate to blank trace */
+                        } while(bv && (bcnt--));
+                if(bv)
+                        {
+                        subname = bv->bvname;
+                        if(GLOBALS->hier_max_level)
+                                subname = hier_extract(subname, GLOBALS->hier_max_level);
+                        }
+                }
+        }
+                         
+  populateBuffer(t, subname, buf);
 
   UpdateSigValue (t);		/* in case it's stale on nonprop */
 
-  bufclen = 0;
-  sbuf[0] = 0;
-
-  if ((t->name) && (t->shift))
-    {
-      sbuf[0] = '(';
-      reformat_time (sbuf + 1, t->shift, GLOBALS->time_dimension);
-      strcpy (sbuf + (bufclen = strlen (sbuf + 1) + 1), ")");
-      bufclen++;
-    }
-
-  if ((!t->vector) && (t->n.nd) && (t->n.nd->array_height))
-    {
-      bufclen += sprintf (sbuf + strlen (sbuf), "{%d}", t->n.nd->this_row);
-    }
-
-
   liney = ((i + 2) * GLOBALS->fontheight) - 2;
 
   texty = liney - (GLOBALS->signalfont->descent);
@@ -2823,31 +2955,29 @@ pr_RenderSig (pr_context * prc, Trptr t, int i)
   {
     int maxwidth = 0;
 
-    if (t->name)
-      maxwidth = strlen (t->name) + bufclen;
+    if (buf)
+      maxwidth = strlen (buf);
     if ((t->asciivalue) && (!(t->flags & TR_EXCLUDE)))
       maxwidth += strlen (t->asciivalue);
     if (maxwidth)
       {
 	gdouble realwidth;
-	char *buf;
-	buf = wave_alloca (maxwidth + 1);
-	buf[0] = 0;
-	if (t->name)
+	char *cbuf;
+	cbuf = wave_alloca (maxwidth + 1);
+	cbuf[0] = 0;
+	if (buf[0])
 	  {
-	    strcpy (buf, t->name);
-	    if (bufclen)
-	      strcat (buf, sbuf);
+	    strcpy (cbuf, buf);
 	  }
 	if ((t->asciivalue) && (!(t->flags & TR_EXCLUDE)))
-	  strcat (buf, t->asciivalue);
+	  strcat (cbuf, t->asciivalue);
 
 	realwidth = maxwidth * GLOBALS->ps_chwidth_print_c_1;
 
 	if (maxwidth == 0)
 	  return (retval);
 	pr_setgray (prc, 0.0);
-	pr_draw_string (prc, 3, texty - 1, buf, realwidth,
+	pr_draw_string (prc, 3, texty - 1, cbuf, realwidth,
 			GLOBALS->signalfont->ascent -
 			GLOBALS->signalfont->descent);
       }
@@ -2979,8 +3109,29 @@ print_mif_image (FILE * wave, gdouble px, gdouble py)
 }
 
 /*
- * $Id: print.c,v 1.29 2010/03/14 07:09:49 gtkwave Exp $
+ * $Id: print.c,v 1.36 2010/04/14 18:45:37 gtkwave Exp $
  * $Log: print.c,v $
+ * Revision 1.36  2010/04/14 18:45:37  gtkwave
+ * allow data values for secondary transaction traces
+ *
+ * Revision 1.35  2010/04/14 04:21:46  gtkwave
+ * update populateBuffer() usage
+ *
+ * Revision 1.34  2010/04/10 03:32:00  gtkwave
+ * allow transaction traces to scroll off top of screen yet still be visible
+ *
+ * Revision 1.33  2010/04/09 20:52:33  gtkwave
+ * add extension traces for extension transactions
+ *
+ * Revision 1.32  2010/04/01 03:10:58  gtkwave
+ * time warp fixes
+ *
+ * Revision 1.31  2010/03/31 15:42:47  gtkwave
+ * added preliminary transaction filter support
+ *
+ * Revision 1.30  2010/03/24 23:05:10  gtkwave
+ * added RealToBits menu option
+ *
  * Revision 1.29  2010/03/14 07:09:49  gtkwave
  * removed ExtNode and merged with Node
  *
