@@ -1446,12 +1446,12 @@ if(t)
 		if(t->vector)
 			{
 			/* this is currently unused as vectors are exploded into single bits */
-			vptr v = bsearch_vector(t->n.vec, GLOBALS->tims.marker);
+			vptr v = bsearch_vector(t->n.vec, GLOBALS->tims.marker - t->shift);
                         rc = convert_ascii(t, v);
 			}
 			else
 			{
-			hptr h_ptr = bsearch_node(t->n.nd, GLOBALS->tims.marker);
+			hptr h_ptr = bsearch_node(t->n.nd, GLOBALS->tims.marker - t->shift);
 			if(h_ptr)
 				{
 				if(!t->n.nd->extvals)
@@ -1465,7 +1465,7 @@ if(t)
 						{
 						if(!(h_ptr->flags&HIST_STRING))
 							{
-							rc = convert_ascii_real((double *)h_ptr->v.h_vector);
+							rc = convert_ascii_real(t, (double *)h_ptr->v.h_vector);
 							}
 							else
 							{
@@ -1611,14 +1611,14 @@ while(t)
                         {
                         int i;
                         nptr *nodes;
-                        vptr v = (GLOBALS->tims.marker != -1) ? bsearch_vector(t->n.vec, GLOBALS->tims.marker) : NULL;
+                        vptr v = (GLOBALS->tims.marker != -1) ? bsearch_vector(t->n.vec, GLOBALS->tims.marker - t->shift) : NULL;
 			unsigned char *bits = v ? (v->v) : NULL;
 			char *first_str = NULL;
 			int coalesce_pass = 1;
                                         
                         nodes=t->n.vec->bits->nodes;
 
-			for(i=0;i<t->n.vec->nbits;i++)
+			for(i=0;i<t->n.vec->bits->nnbits;i++)
 				{
 				if(!nodes[i]->expansion)
 					{
@@ -1644,7 +1644,7 @@ while(t)
 
 			if(coalesce_pass)
 				{
-				if(t->n.vec->nbits < 2)
+				if(t->n.vec->bits->nnbits < 2)
 					{
 					coalesce_pass = 0;
 					}
@@ -1655,7 +1655,7 @@ while(t)
 					char *pl = strrchr(strl, '[');
 					int lidx = atoi(pl+1);
 
-					nptr nr = nodes[t->n.vec->nbits - 1];
+					nptr nr = nodes[t->n.vec->bits->nnbits - 1];
 					char *strr = append_array_row(nr);
 					char *pr = strrchr(strr, '[');
 					int ridx = atoi(pr+1);
@@ -1687,7 +1687,7 @@ while(t)
 				}
 
 			if(!coalesce_pass)
-                        for(i=0;i<t->n.vec->nbits;i++)
+                        for(i=0;i<t->n.vec->bits->nnbits;i++)
                                 {
                                 if(nodes[i]->expansion)
                                         {
@@ -2049,6 +2049,21 @@ char *emit_gtkwave_savefile_formatted_entries_in_tcl_list(Trptr t, gboolean use_
 					}
 				}
 
+			/* NOT an else! */
+			if(t->flags & TR_TTRANSLATED)
+				{
+				if(t->t_filter && GLOBALS->ttranssel_filter[t->t_filter])
+					{
+					one_entry = make_message("^<%d %s\n", t->t_filter, GLOBALS->ttranssel_filter[t->t_filter]);
+					WAVE_OE_ME
+					}
+					else
+					{
+					one_entry = make_message("^<%d %s\n", 0, "disabled");
+					WAVE_OE_ME
+					}
+				}
+
 			if(t->vector)
 				{
 				int i;
@@ -2061,11 +2076,12 @@ char *emit_gtkwave_savefile_formatted_entries_in_tcl_list(Trptr t, gboolean use_
 				bits = t->n.vec->bits;
 				ba = bits ? bits->attribs : NULL;
 
-				one_entry = make_message("%c{%s}", ba ? ':' : '#', t->n.vec->name);
+				one_entry = make_message("%c{%s}", ba ? ':' : '#',
+					t->n.vec->transaction_cache ? t->n.vec->transaction_cache->bvname : t->n.vec->bvname);
 				WAVE_OE_ME
 
 				nodes=t->n.vec->bits->nodes;
-				for(i=0;i<t->n.vec->nbits;i++)
+				for(i=0;i<t->n.vec->bits->nnbits;i++)
 					{
 					if(nodes[i]->expansion)
 						{
@@ -2717,8 +2733,23 @@ void make_tcl_interpreter(char *argv[])
 
 
 /*
- * $Id: tcl_helper.c,v 1.73 2010/03/18 17:12:37 gtkwave Exp $
+ * $Id: tcl_helper.c,v 1.78 2010/04/07 01:50:45 gtkwave Exp $
  * $Log: tcl_helper.c,v $
+ * Revision 1.78  2010/04/07 01:50:45  gtkwave
+ * improved name handling for bvname, add $next transaction operation
+ *
+ * Revision 1.77  2010/04/04 19:09:57  gtkwave
+ * rename name->bvname in struct BitVector for easier grep tracking
+ *
+ * Revision 1.76  2010/04/01 03:10:58  gtkwave
+ * time warp fixes
+ *
+ * Revision 1.75  2010/03/31 20:41:03  gtkwave
+ * nbits versus nnbits fix
+ *
+ * Revision 1.74  2010/03/24 23:05:10  gtkwave
+ * added RealToBits menu option
+ *
  * Revision 1.73  2010/03/18 17:12:37  gtkwave
  * pedantic warning cleanups
  *
